@@ -30,6 +30,8 @@
 
 #include <glib.h>
 
+G_BEGIN_DECLS
+
 /**
  * ATK_MAJOR_VERSION:
  *
@@ -50,7 +52,7 @@
  *
  * Since: 2.7.4
  */
-#define ATK_MINOR_VERSION (58)
+#define ATK_MINOR_VERSION (59)
 
 /**
  * ATK_MICRO_VERSION:
@@ -72,7 +74,7 @@
  *
  * Since: 2.7.4
  */
-#define ATK_BINARY_AGE    (25810)
+#define ATK_BINARY_AGE    (25910)
 
 /**
  * ATK_INTERFACE_AGE:
@@ -189,7 +191,7 @@
 /**
  * ATK_VERSION_2_32:
  *
- * A macro that evaluates to the 2.30 version of ATK, in a format
+ * A macro that evaluates to the 2.32 version of ATK, in a format
  * that can be used by the C pre-processor.
  *
  * Since: 2.52
@@ -473,4 +475,6 @@ guint atk_get_interface_age (void) G_GNUC_CONST;
 #define atk_binary_age atk_get_binary_age ()
 #define atk_interface_age atk_get_interface_age ()
 
+G_END_DECLS
+
 #endif /* __ATK_VERSION_H__ */
